@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005001';
+our $VERSION   = '0.005002';
 
 has _order =>
   is            => 'rw',
@@ -60,9 +60,15 @@ has [ 'reader', 'writer', 'accessor', 'clearer', 'predicate' ] =>
 has isa =>
   is            => 'bare',
   isa           => Str|Object,
-  reader        => '_isa',
+  reader        => '_isa', # collision with UNIVERSAL::isa
   init_arg      => 'isa';
 
+has does =>
+  is            => 'bare',
+  isa           => Str|Object,
+  reader        => '_does', # collision with Mite's does method
+  init_arg      => 'does';
+
 has type =>
   is            => 'lazy',
   isa           => Object|Undef,
@@ -104,7 +110,8 @@ has documentation =>
 has handles =>
   is            => rw,
   isa           => HashRef->of( Str )->plus_coercions( ArrayRef, q{+{ map { $_ => $_ } @$_ }} ),
-  predicate     => true;
+  predicate     => true,
+  coerce        => true;
 
 has alias =>
   is            => rw,
@@ -123,6 +130,16 @@ sub _q          { shift; join q[, ], map B::perlstring($_), @_ }
 sub _q_name     { B::perlstring( shift->name ) }
 sub _q_init_arg { B::perlstring( shift->init_arg ) }
 
+for my $function ( qw/ carp croak confess / ) {
+    no strict 'refs';
+    *{"_function_for_$function"} = sub {
+        my $self = shift;
+        return $self->class->${\"_function_for_$function"}
+            if ref $self->class;
+        return "require Carp && Carp::$function";
+    };
+}
+
 my @method_name_generator = (
     { # public
         reader      => sub { "get_$_" },
@@ -245,18 +262,33 @@ sub _all_aliases {
 sub _build_type {
     my $self = shift;
 
-    my $isa = $self->_isa
-        or return undef;
+    my ( $fallback, $string );
+    if ( my $isa = $self->_isa ) {
+        $string   = $isa;
+        $fallback = [ 'make_class_type' ];
+    }
+    elsif ( my $does = $self->_does ) {
+        $string   = $does;
+        $fallback = [ 'make_role_type' ];
+    }
+    else {
+        return undef;
+    }
 
-    require Type::Utils;
-    my $type = Type::Utils::dwim_type(
-        $isa,
-        fallback => [ 'make_class_type' ],
-        for      => $self->class->name,
-    );
+    my $type;
+    if ( ref $string ) {
+        $type = $string;
+    }
+    else {
+        require Type::Utils;
+        $type = Type::Utils::dwim_type(
+            $string,
+            fallback => $fallback,
+            for      => $self->class->name,
+        );
 
-    $type
-        or croak sprintf 'Type %s cannot be found', $isa;
+        $type or croak sprintf 'Type %s cannot be found', $string;
+    }
 
     $type->can_be_inlined
         or croak sprintf 'Type %s cannot be inlined', $type->display_name;
@@ -319,8 +351,8 @@ sub _compile_checked_default {
         $default = $self->_compile_coercion( $default );
     }
 
-    return sprintf 'do { my $default_value = %s; %s or do { require Carp; Carp::croak(sprintf "Type check failed in default: %%s should be %%s", %s, %s) }; $default_value }',
-        $default, $type->inline_check('$default_value'), $self->_q($self->name), $self->_q($type->display_name);
+    return sprintf 'do { my $default_value = %s; %s or %s( "Type check failed in default: %%s should be %%s", %s, %s ); $default_value }',
+        $default, $type->inline_check('$default_value'), $self->_function_for_croak, $self->_q($self->name), $self->_q($type->display_name);
 }
 
 sub _compile_default {
@@ -373,8 +405,9 @@ sub compile_init {
                 $code .= sprintf 'my $value = %s; ', $self->_compile_coercion( $valuevar );
                 $valuevar = '$value';
             }
-            $code .= sprintf '%s or require Carp && Carp::croak(sprintf "Type check failed in constructor: %%s should be %%s", %s, %s); ',
+            $code .= sprintf '%s or %s( "Type check failed in constructor: %%s should be %%s", %s, %s ); ',
                 $type->inline_check( $valuevar ),
+                $self->_function_for_croak,
                 $self->_q_init_arg,
                 $self->_q( $type->display_name );
             $code .= sprintf '%s->{%s} = %s; ',
@@ -404,8 +437,8 @@ sub compile_init {
     elsif ( defined $init_arg
     and $self->required
     and not ($self->has_default || $self->has_builder) ) {
-        $code .= sprintf ' else { require Carp; Carp::croak("Missing key in constructor: %s") }',
-            $init_arg;
+        $code .= sprintf ' else { %s( "Missing key in constructor: %s" ) }',
+            $self->_function_for_croak, $init_arg;
     }
 
     if ( $self->weak_ref ) {
@@ -436,8 +469,8 @@ my %code_template;
                 $self->_q_name, $self->_q_name, $self->_q_name, $self->_compile_checked_default( '$_[0]' );
         }
         unless ( $arg{no_croak} ) {
-            $code = sprintf '@_ > 1 ? require Carp && Carp::croak("%s is a read-only attribute of @{[ref $_[0]]}") : %s',
-                $self->name, $code;
+            $code = sprintf '@_ > 1 ? %s( "%s is a read-only attribute of @{[ref $_[0]]}" ) : %s',
+                $self->_function_for_croak, $self->name, $code;
         }
         return $code;
     },
@@ -445,8 +478,8 @@ my %code_template;
         my $self = shift;
         my %arg = @_;
         my $reader = $code_template{reader}->( $self, no_croak => true );
-        return sprintf 'my $object = do { %s }; require Scalar::Util && Scalar::Util::blessed($object) or require Carp && Carp::croak("%s is not a blessed object"); $object',
-            $reader, $self->name;
+        return sprintf 'my $object = do { %s }; require Scalar::Util && Scalar::Util::blessed($object) or %s( "%s is not a blessed object" ); $object',
+            $reader, $self->_function_for_croak, $self->name;
     },
     writer => sub {
         my $self = shift;
@@ -463,8 +496,8 @@ my %code_template;
                 $code .= sprintf 'my $value = %s; ', $self->_compile_coercion($valuevar);
                 $valuevar = '$value';
             }
-            $code .= sprintf '%s or require Carp && Carp::croak(sprintf "Type check failed in %%s: value should be %%s", %s, %s); $_[0]{%s} = %s;',
-                $type->inline_check($valuevar), $self->_q( $arg{label} // 'writer' ), $self->_q( $type->display_name ), $self->_q_name, $valuevar;
+            $code .= sprintf '%s or %s( "Type check failed in %%s: value should be %%s", %s, %s ); $_[0]{%s} = %s;',
+                $type->inline_check($valuevar), $self->_function_for_croak, $self->_q( $arg{label} // 'writer' ), $self->_q( $type->display_name ), $self->_q_name, $valuevar;
         }
         else {
             $code .= sprintf '$_[0]{%s} = $_[1];', $self->_q_name;
