@@ -7,7 +7,7 @@ use Mite::Miteception;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005001';
+our $VERSION   = '0.005002';
 
 use Path::Tiny;
 use mro;
@@ -182,7 +182,7 @@ sub compilation_stages {
         _compile_package
         _compile_uses_mite
         _compile_pragmas
-        _compile_constants
+        _compile_imported_functions
         _compile_extends
         _compile_with
         _compile_new
@@ -302,8 +302,8 @@ sub _compile_strict_constructor {
             : $enum->inline_check( '$_' );
     };
 
-    return sprintf 'my @unknown = grep not( %s ), keys %%{%s}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));',
-        $check, $argvar;
+    return sprintf 'my @unknown = grep not( %s ), keys %%{%s}; @unknown and %s( "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );',
+        $check, $argvar, $self->_function_for_croak;
 }
 
 sub _compile_buildargs {
