@@ -1,6 +1,7 @@
 {
 package Mite::Compiled;
 our $USES_MITE = "Mite::Class";
+our $MITE_SHIM = "Mite::Shim";
 use strict;
 use warnings;
 
@@ -13,11 +14,11 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Initialize attributes
-    if ( exists $args->{"file"} ) { my $value = do { my $to_coerce = $args->{"file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "file", "Path"); $self->{"file"} = $value;  };
-    if ( exists $args->{"source"} ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{"source"}) and $args->{"source"}->isa(q[Mite::Source]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "source", "InstanceOf[\"Mite::Source\"]"); $self->{"source"} = $args->{"source"};  } else { require Carp; Carp::croak("Missing key in constructor: source") } require Scalar::Util && Scalar::Util::weaken($self->{"source"});
+    if ( exists $args->{"file"} ) { my $value = do { my $to_coerce = $args->{"file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or Mite::Shim::croak( "Type check failed in constructor: %s should be %s", "file", "Path" ); $self->{"file"} = $value;  };
+    if ( exists $args->{"source"} ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{"source"}) and $args->{"source"}->isa(q[Mite::Source]) }) or Mite::Shim::croak( "Type check failed in constructor: %s should be %s", "source", "InstanceOf[\"Mite::Source\"]" ); $self->{"source"} = $args->{"source"};  } else { Mite::Shim::croak( "Missing key in constructor: source" ) } require Scalar::Util && Scalar::Util::weaken($self->{"source"});
 
     # Enforce strict constructor
-    my @unknown = grep not( /\A(?:file|source)\z/ ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
+    my @unknown = grep not( /\A(?:file|source)\z/ ), keys %{$args}; @unknown and Mite::Shim::croak( "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
     # Call BUILD methods
     $self->BUILDALL( $args ) if ( ! $no_build and @{ $meta->{BUILD} || [] } );
@@ -83,7 +84,7 @@ sub does {
 my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for file
-sub file { @_ > 1 ? require Carp && Carp::croak("file is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{"file"}) ? $_[0]{"file"} : ( $_[0]{"file"} = do { my $default_value = do { my $to_coerce = do { my $method = $Mite::Compiled::__file_DEFAULT__; $_[0]->$method }; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Path::Tiny]) }) or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "file", "Path") }; $default_value } ) ) }
+sub file { @_ > 1 ? Mite::Shim::croak( "file is a read-only attribute of @{[ref $_[0]]}" ) : ( exists($_[0]{"file"}) ? $_[0]{"file"} : ( $_[0]{"file"} = do { my $default_value = do { my $to_coerce = do { my $method = $Mite::Compiled::__file_DEFAULT__; $_[0]->$method }; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Path::Tiny]) }) or Mite::Shim::croak( "Type check failed in default: %s should be %s", "file", "Path" ); $default_value } ) ) }
 
 # Accessors for source
 if ( $__XS ) {
@@ -93,7 +94,7 @@ if ( $__XS ) {
     );
 }
 else {
-    *source = sub { @_ > 1 ? require Carp && Carp::croak("source is a read-only attribute of @{[ref $_[0]]}") : $_[0]{"source"} };
+    *source = sub { @_ > 1 ? Mite::Shim::croak( "source is a read-only attribute of @{[ref $_[0]]}" ) : $_[0]{"source"} };
 }
 
 
