@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005001';
+our $VERSION   = '0.005002';
 
 has sources =>
   is            => ro,
@@ -177,12 +177,17 @@ sub inject_mite_functions {
     for my $f ( qw/ true false / ) {
         next unless $requested->( $f, $want_bool );
         *{"$package\::$f"} = \&{"$shim\::$f"};
-        $pkg->constants->{$f} = "$shim\::$f";
+        $pkg->imported_functions->{$f} = "$shim\::$f";
     }
     for my $f ( qw/ ro rw rwp lazy bare / ) {
         next unless $requested->( $f, $want_is );
         *{"$package\::$f"} = \&{"$shim\::$f"};
-        $pkg->constants->{$f} = "$shim\::$f";
+        $pkg->imported_functions->{$f} = "$shim\::$f";
+    }
+    for my $f ( qw/ carp croak confess / ) {
+        next unless $requested->( $f, false );
+        *{"$package\::$f"} = \&{"$shim\::$f"};
+        $pkg->imported_functions->{$f} = "$shim\::$f";
     }
 }
 
