@@ -6,7 +6,7 @@ package Mite::Role;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005001';
+our $VERSION   = '0.005002';
 
 use Path::Tiny;
 use B ();
@@ -27,7 +27,12 @@ has name =>
 
 has shim_name =>
   is            => rw,
-  isa           => Str;
+  isa           => Str,
+  lazy          => true,
+  builder       => sub {
+    my $self = shift;
+    eval { $self->project->config->data->{shim} } // 'Mite::Shim'
+  };
 
 has source =>
   is            => rw,
@@ -40,7 +45,7 @@ has roles =>
   isa           => ArrayRef[Object],
   builder       => sub { [] };
 
-has constants =>
+has imported_functions =>
   is            => ro,
   isa           => HashRef[Str],
   builder       => sub { {} };
@@ -115,9 +120,11 @@ sub methods_to_import_from_roles {
         my %exported = %{ $role->methods_to_export };
         for my $name ( sort keys %exported ) {
             if ( defined $methods{$name} and  $methods{$name} ne $exported{$name} ) {
-                require Carp;
-                Carp::croak "Conflict between %s and %s; %s must implement %s\n",
-                    $methods{$name}, $exported{$name}, $self->name, $name;
+                require Mite::Shim;
+                Mite::Shim::croak(
+                    "Conflict between %s and %s; %s must implement %s\n",
+                    $methods{$name}, $exported{$name}, $self->name, $name,
+                );
             }
             else {
                 $methods{$name} = $exported{$name};
@@ -261,12 +268,24 @@ sub does_list {
     );
 }
 
+for my $function ( qw/ carp croak confess / ) {
+    no strict 'refs';
+    *{"_function_for_$function"} = sub {
+        my $self = shift;
+        return $function
+            if $self->imported_functions->{$function};
+        return sprintf '%s::%s', $self->shim_name, $function
+            if $self->shim_name;
+        return "require Carp && Carp::$function";
+    };
+}
+
 sub compilation_stages {
     return qw(
         _compile_package
         _compile_uses_mite
         _compile_pragmas
-        _compile_constants
+        _compile_imported_functions
         _compile_with
         _compile_does
         _compile_composed_methods
@@ -345,16 +364,15 @@ sub _compile_composed_methods {
     return $code;
 }
 
-sub _compile_constants {
+sub _compile_imported_functions {
     my $self = shift;
-    my %const = %{ $self->constants }
-        or return;
+    my %func = %{ $self->imported_functions } or return;
 
     return join "\n",
         'BEGIN {',
         map(
-            sprintf( '    *%s = \&%s;',  $_, $const{$_} ),
-            sort keys %const
+            sprintf( '    *%s = \&%s;',  $_, $func{$_} ),
+            sort keys %func
         ),
         '};',
         '';
@@ -420,6 +438,7 @@ sub _compile_callback {
         || eval { $self->project->config->data->{shim} }
         || 'Mite::Shim'
     );
+    my $croak = $self->_function_for_croak;
     my $missing_methods = '()';
     if ( @required ) {
         require B;
@@ -427,7 +446,7 @@ sub _compile_callback {
             join q[, ], map B::perlstring( $_ ), @required;
     }
 
-    return sprintf <<'CODE', $missing_methods, $role_list, $shim;
+    return sprintf <<'CODE', $missing_methods, $croak, $role_list, $croak, $shim;
 # Callback which classes consuming this role will call
 sub __FINALIZE_APPLICATION__ {
     my ( $me, $target, $args ) = @_;
@@ -444,13 +463,12 @@ sub __FINALIZE_APPLICATION__ {
 
     my @missing_methods;
     @missing_methods = %s
-        and require Carp
-        and Carp::croak( "$me requires $target to implement methods: " . join q[, ], @missing_methods );
+        and %s( "$me requires $target to implement methods: " . join q[, ], @missing_methods );
 
     my @roles = ( %s );
     my %%nextargs = %%{ $args || {} };
     ( $nextargs{-indirect} ||= 0 )++;
-    die "PANIC!" if $nextargs{-indirect} > 100;
+    %s( "PANIC!" ) if $nextargs{-indirect} > 100;
     for my $role ( @roles ) {
         $role->__FINALIZE_APPLICATION__( $target, { %%nextargs } );
     }
